==> moodle-1.5-pgsql.tgz: moodle/lang/nl/hotpot.php <==
<?PHP // $Id$ 
      // hotpot.php - created with Moodle 1.5 ALPHA (2005051500)


$string['abandoned'] = 'verlaten';
$string['allattempts'] = 'alle pogingen';
$string['allmycourses'] = 'al mijn vakken';
$string['average'] = 'Gemiddelde';
$string['bestattempt'] = 'beste poging';
$string['checks'] = 'controles';
$string['clues'] = 'Ideen';
$string['copiedtoclipboard'] = 'De inhoud van deze pagina is naar het klembord gekopieerd';
$string['copytoclipboard'] = 'Kopieer naar klembord';
$string['correct'] = 'juist';
$string['deleteabandoned'] = 'Verwijder verlaten';
$string['deleteabandonedcheck'] = 'Wil je echt alle $a verlaten pogingen verwijderen?';
$string['deletedattempts'] = '$a pogingen werden verwijderd';
$string['deletedresponses'] = '$a antwoorden werden verwijderd';
$string['enterafilename'] = 'Geef een bestandsnaam';
$string['filetype'] = 'Bestandstype';
$string['forceplugins'] = 'Verplicht mediaplugins';
$string['giveup'] = 'Geef op';
$string['hints'] = 'hints';
$string['ignored'] = 'genegeerd';
$string['inprogress'] = 'lopend';
$string['location'] = 'Bestandslocatie';
$string['modulename'] = 'Hot Potatoes test';
$string['modulenameplural'] = 'Hot Potatoes testen';
$string['navigation'] = 'navigatie';
$string['navigation_bar'] = 'Moodle navigatiebalk';
$string['navigation_buttons'] = 'Knoppen van Hot Potatoestest';
$string['navigation_frame'] = 'Moodle navigatieframe';
$string['navigation_give_up'] = 'Een enkele \"Geef op\" knop';
$string['navigation_iframe'] = 'Ingebed <IFRAME>';
$string['navigation_none'] = 'Geen';
$string['noactivity'] = 'Geen activiteit';
$string['noresponses'] = 'Er is geen informatie gevonden over individuele vragen en antwoorden.';
$string['outputformat'] = 'Output-opmaak';
$string['outputformat_best'] = 'beste';
$string['outputformat_flash'] = 'Flash';
$string['outputformat_mobile'] = 'mobiel';
$string['outputformat_v3'] = 'V3';
$string['outputformat_v4'] = 'V4';
$string['outputformat_v5'] = 'V5';
$string['outputformat_v6'] = 'V6';
$string['outputformat_v6_plus'] = 'V6+';
$string['penalties'] = 'straffen';
$string['questionshort'] = 'Vr-$a';
$string['quiztype'] = 'Type test';
$string['resultssaved'] = 'Testresultaten zjn bewaard';
$string['score'] = 'cijfer';
$string['selectattempt'] = 'Kies een poging';
$string['showhtmlsource'] = 'Toon HTML-bron';
$string['shownextquiz'] = 'Toon volgende test?';
$string['showxmlsource'] = 'Toon XML-bron';
$string['showxmltree'] = 'Toon XML-boom';
$string['thiscourse'] = 'dit vak';
$string['weighting'] = 'weging';
$string['wrong'] = 'foutief';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/nl/hotpot.php <==
<?PHP // $Id$ 
      // hotpot.php - created with Moodle 1.5 ALPHA (2005051500)


$string['abandoned'] = 'verlaten';
$string['allattempts'] = 'alle pogingen';
$string['allmycourses'] = 'al mijn cursussen';
$string['average'] = 'Gemiddelde';
$string['bestattempt'] = 'beste poging';
$string['checks'] = 'controles';
$string['clues'] = 'Ideen';
$string['copiedtoclipboard'] = 'De inhoud van deze pagina is naar het klembord gekopieerd';
$string['copytoclipboard'] = 'Kopieer naar klembord';
$string['correct'] = 'juist';
$string['deleteabandoned'] = 'Verwijder verlaten';
$string['deleteabandonedcheck'] = 'Wil je echt alle $a verlaten pogingen verwijderen?';
$string['deletedattempts'] = '$a pogingen werden verwijderd';
$string['deletedresponses'] = '$a antwoorden werden verwijderd';
$string['enterafilename'] = 'Geef een bestandsnaam';
$string['filetype'] = 'Bestandstype';
$string['forceplugins'] = 'Verplicht mediaplugins';
$string['giveup'] = 'Geef op';
$string['hints'] = 'hints';
$string['ignored'] = 'genegeerd';
$string['inprogress'] = 'lopend';
$string['location'] = 'Bestandslocatie';
$string['modulename'] = 'Hot Potatoes-test';
$string['modulenameplural'] = 'Hot Potatoes-testen';
$string['navigation'] = 'navigatie';
$string['navigation_bar'] = 'Moodle-navigatiebalk';
$string['navigation_buttons'] = 'Knoppen van Hot Potatoes-test';
$string['navigation_frame'] = 'Moodle-navigatieframe';
$string['navigation_give_up'] = 'Een enkele \"Geef op\" knop';
$string['navigation_iframe'] = 'Ingebed <IFRAME>';
$string['navigation_none'] = 'Geen';
$string['noactivity'] = 'Geen activiteit';
$string['noresponses'] = 'Er is geen informatie gevonden over individuele vragen en antwoorden.';
$string['outputformat'] = 'Output-opmaak';
$string['outputformat_best'] = 'beste';
$string['outputformat_flash'] = 'Flash';
$string['outputformat_mobile'] = 'mobiel';
$string['outputformat_v3'] = 'V3';
$string['outputformat_v4'] = 'V4';
$string['outputformat_v5'] = 'V5';
$string['outputformat_v6'] = 'V6';
$string['outputformat_v6_plus'] = 'V6+';
$string['penalties'] = 'straffen';
$string['questionshort'] = 'Vr-$a';
$string['quiztype'] = 'Type test';
$string['resultssaved'] = 'Testresultaten zjn bewaard';
$string['score'] = 'cijfer';
$string['selectattempt'] = 'Kies een poging';
$string['showhtmlsource'] = 'Toon HTML-bron';
$string['shownextquiz'] = 'Toon volgende test?';
$string['showxmlsource'] = 'Toon XML-bron';
$string['showxmltree'] = 'Toon XML-boom';
$string['thiscourse'] = 'deze cursus';
$string['weighting'] = 'weging';
$string['wrong'] = 'foutief';

?>
